@@ -1,7 +1,7 @@
 /*
  *  JIT compile ClamAV bytecode.
  *
- *  Copyright (C) 2013-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2009-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin, Andy Ragusa
@@ -106,7 +106,7 @@ void LLVMInitializePowerPCAsmPrinter();
 
 #include "llvm/IR/Dominators.h"
 
-//#define TIMING
+// #define TIMING
 #undef TIMING
 
 #include "llvm/Config/llvm-config.h"
@@ -1973,7 +1973,7 @@ static void *bytecode_watchdog(void *arg)
     } while (1);
     watchdog_running = 0;
     if (cli_debug_flag)
-        cli_dbgmsg_no_inline("bytecode watchdog quiting\n");
+        cli_dbgmsg_no_inline("bytecode watchdog quitting\n");
     pthread_mutex_unlock(&watchdog_mutex);
     return NULL;
 }
