@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm
@@ -201,7 +201,6 @@ static inline cl_error_t matcher_run(const struct cli_matcher *root,
             break;
     }
 
-#if HAVE_PCRE
     /* due to logical triggered, pcres cannot be evaluated until after full subsig matching */
     /* cannot save pcre execution state without possible evasion; must scan entire buffer */
     /* however, scanning the whole buffer may require the whole buffer being loaded into memory */
@@ -245,7 +244,7 @@ static inline cl_error_t matcher_run(const struct cli_matcher *root,
             ret = cli_pcre_scanbuf(buffer, length, virname, acres, root, mdata, poffdata, ctx);
         }
     }
-#endif /* HAVE_PCRE */
+
     /* end experimental fragment */
 
     if (ctx && ret == CL_VIRUS) {
@@ -899,7 +898,7 @@ static cl_error_t lsig_eval(cli_ctx *ctx, struct cli_matcher *root, struct cli_a
              * Create an fmap window into our current fmap using the original offset & length, and rescan as the new type
              *
              * TODO: Unsure if creating an fmap is the right move, or if we should rescan with the current fmap as-is,
-             * since it's not really a container so much as it is type reassignment. This new fmap layer protect agains
+             * since it's not really a container so much as it is type reassignment. This new fmap layer protect against
              * a possible infinite loop by applying the scan recursion limit, but maybe there's a better way?
              * Testing with both HandlerType type reassignment sigs + Container/Intermediates sigs should indicate if
              * a change is needed.
@@ -1406,14 +1405,14 @@ cl_error_t cli_scan_fmap(cli_ctx *ctx, cli_file_t ftype, bool filetype_only, str
     /*
      * Evaluate the logical expressions for clamav logical signatures and YARA rules.
      */
-    // Evalute for the target-specific signature AC matches.
+    // Evaluate for the target-specific signature AC matches.
     if (NULL != target_ac_root) {
         if (ret != CL_VIRUS) {
             ret = cli_exp_eval(ctx, target_ac_root, &target_ac_data, &info, (const char *)refhash);
         }
     }
 
-    // Evalute for the generic signature AC matches.
+    // Evaluate for the generic signature AC matches.
     if (NULL != generic_ac_root) {
         if (ret != CL_VIRUS) {
             ret = cli_exp_eval(ctx, generic_ac_root, &generic_ac_data, &info, (const char *)refhash);
@@ -1469,14 +1468,14 @@ done:
             continue;                                                     \
     }
 
-cl_error_t cli_matchmeta(cli_ctx *ctx, const char *fname, size_t fsizec, size_t fsizer, int encrypted, unsigned int filepos, int res1, void *res2)
+cl_error_t cli_matchmeta(cli_ctx *ctx, const char *fname, size_t fsizec, size_t fsizer, int encrypted, unsigned int filepos, int res1)
 {
     const struct cli_cdb *cdb;
     cl_error_t ret = CL_SUCCESS;
 
-    cli_dbgmsg("CDBNAME:%s:%llu:%s:%llu:%llu:%d:%u:%u:%p\n",
+    cli_dbgmsg("CDBNAME:%s:%llu:%s:%llu:%llu:%d:%u:%u\n",
                cli_ftname(cli_recursion_stack_get_type(ctx, -1)), (long long unsigned)fsizec, fname, (long long unsigned)fsizec, (long long unsigned)fsizer,
-               encrypted, filepos, res1, res2);
+               encrypted, filepos, res1);
 
     if (ctx->engine && ctx->engine->cb_meta) {
         if (ctx->engine->cb_meta(cli_ftname(cli_recursion_stack_get_type(ctx, -1)), fsizec, fname, fsizer, encrypted, filepos, ctx->cb_ctx) == CL_VIRUS) {
